## Hothorn - using random forests for survival analysis, using log
## transformation on survival times, and usual random forests
## afterwards.

library(survHD)
data(beer.exprs,package="pensim")
data(beer.survival,package="pensim")
beerY <- with(beer.survival,Surv(os,status))
beerX <- t(as.matrix(beer.exprs))
beerX <- beerX[,1:200]
colnames(beerX) <- make.names(colnames(beerX),unique=TRUE)
beerX <- scale(beerX)  ##scale everything for testing.
##
## data(golub)
## golubY <- golub[,1]
## golubX <- as.matrix(golub[,-1])
set.seed(4)
allind <- 1:nrow(beerX)
learnind <- sample(allind,size=round(length(allind)*9/10))
testind <- allind[-learnind]
mytimegrid <- sort(c(0.0,beerY[beerY[,2]==1,1]))[-8]  #to match penalized default time grid.

fit.plusminus <- plusminussurv(X=beerX,y=beerY, lambda=10)
predict(fit.plusminus,newdata=beerX[testind,])
getSurvProbs(fit.plusminus,beerX,timegrid=mytimegrid,gbm=TRUE)
residuals(fit.plusminus@model[[1]], X=beerX[1:5,], y=beerY[1:5,])

fit.unicox <- unicoxsurv(X=beerX,y=beerY,learnind=learnind,lambda=10)
predict(fit.unicox,newdata=beerX[testind,])
##getLP.r: Linear predictor not available for object class  unicoxsurv
getSurvProbs(fit.unicox,beerX,timegrid=mytimegrid,gbm=TRUE)


fit.ridge <- penalizedsurv(X=beerX,y=beerY, learnind=learnind, penalty="ridge", fold=10)
predict(fit.ridge,newdata=beerX[testind,])
cma.probs <- getSurvProbs(fit.ridge,beerX,timegrid=mytimegrid,gbm=TRUE)
penalized.probs <- predict(fit.ridge@model[[1]],penalized=beerX)

prob.diff <- t(sapply(1:nrow(cma.probs@curves), function(i) cma.probs@curves[i,] - penalized.probs@curves[i,-ncol(penalized.probs@curves)]))
all.equal(colMeans(prob.diff)[-1],rep(0,ncol(prob.diff)-1))  ##they are the same

fit.lasso <- penalizedsurv(X=beerX,y=beerY, learnind=learnind, penalty="lasso")
predict(fit.lasso,newdata=beerX[testind,])
getSurvProbs(fit.lasso,beerX,timegrid=mytimegrid,gbm=TRUE)

### generate 25 bootstrap datasets
(seed <- sample(1:1e6,1))
set.seed(seed)
##source("../R/GenerateLearningsets.r")
bootds <- GenerateLearningsets(y = beerY, method = "CV", fold = 8, niter = 2, strat = TRUE)
### run classification()

ridgeclass <- learnsurvival(X=beerX, y=beerY, learningsets = bootds, survmethod=penalizedsurv, lambda=100, penalty="ridge")
plusminusclass <- learnsurvival(X=beerX, y=beerY, learningsets = bootds, survmethod=plusminussurv)
coxboostclass <- learnsurvival(X=beerX, y=beerY, learningsets = bootds, survmethod=coxboostsurv)


evaluationsurv(coxboostclass,measure="harrell.C")
evaluationsurv(coxboostclass,measure="uno.C",tau=60.0)
evaluationsurv(coxboostclass,measure="PredErrorCurve")
evaluationsurv(coxboostclass, measure="CVPLogL")

### Evaluation:
##source("../R/evaluationsurv.r")
eval_iter <- evaluationsurv(plusminusclass, measure="CVPLogL")
eval_iter <- evaluationsurv(plusminusclass, measure="residual", scheme = "obs", type="score")
eval_iter <- evaluationsurv(plusminusclass, measure="residual", scheme = "obs", type="deviance")
eval_iter <- evaluationsurv(plusminusclass, measure="residual", scheme = "obs", type="schoenfeld")
eval_iter <- evaluationsurv(plusminusclass, measure="logplik", scheme = "iter")
eval_iter@score
eval_iter <- evaluationsurv(plusminusclass, measure="hazardratio", scheme = "iter")
eval_iter <- evaluationsurv(plusminusclass, measure="cstatistic", scheme = "iter",tau=1e6)
eval_iter@score
eval_iter <- evaluationsurv(plusminusclass, measure="plainscores", scheme = "iter")
eval_iter <- evaluationsurv(plusminusclass, measure="plainscores", scheme = "obs")

plusminusclass <- learnsurvival(X=beerX[,1:2], y=beerY, learningsets = bootds, classifier=plusminussurv, models=TRUE, probability=2.0, lambda=1e-9)
eval_iter <- evaluationsurv(plusminusclass, measure="logplik", scheme = "iter")
eval_iter@score


### tuning after gene selection with the t.test
##source("../R/evaluationsurv.r")
##source("../R/tune.r")
tuneres <- tune(X = beerX, y = beerY, learningsets = bootds,
                genesellist = list(method = NULL),
##              genesellist = list(method = "coxfilter"), nbgene = 100,
                classifier=plusminussurv, 
                grids = list(lambda = c(1, 10, 100, 1000, 10000)))

### inspect results - needs work.
unlist(best(tuneres))
show(tuneres)
plot(tuneres, iter = 3)

##compare to using optL2 directly
tmp <- optL2(response=beerY,penalized=beerX)

##--------------------------------
## example using an expressionset
##--------------------------------
library(CMAdevel)
data(PMID19318476_eset)
PMID19318476_eset <- PMID19318476_eset[1:200,]

### select learningset
ratio <- 2/3
set.seed(111)
learnind <- sample(ncol(PMID19318476_eset), size=floor(ratio*ncol(PMID19318476_eset)))

##varsel survival example:
fiveCVdat <- GenerateLearningsets(y=PMID19318476_eset$vital_status, method = "CV", fold = 5, strat = TRUE)  ##stratification only occurs with respect to censoring
##source("../R/GeneSelection.r")
varsel_fiveCV <- GeneSelection(X = PMID19318476_eset, y=c("days_to_death","vital_status","living","deceased"), learningsets = fiveCVdat, method = "coxfilter")

### generate 25 bootstrap datasets
(seed <- sample(1:1e6,1))
set.seed(seed)
##source("../R/GenerateLearningsets.r")
bootds <- GenerateLearningsets(y = PMID19318476_eset$vital_status, method = "CV", fold = 5, ntrain = 3, niter = 2, strat = TRUE)
### run classification()
##source("../R/plusminusCMA.r")
##source("../R/survival.r")
plusminusclass <- learnsurvival(X=PMID19318476_eset, y=c("days_to_death","vital_status","living","deceased"), learningsets = bootds, classifier=plusminussurv, mod=TRUE, probability=2.0, lambda=100)

### Evaluation:
##source("../R/evaluationsurv.r")
eval_iter <- evaluationsurv(plusminusclass, measure="residual", scheme = "obs", type="martingale")
eval_iter@score
eval_iter <- evaluationsurv(plusminusclass, measure="residual", scheme = "obs", type="score")
eval_iter <- evaluationsurv(plusminusclass, measure="residual", scheme = "obs", type="deviance")
eval_iter <- evaluationsurv(plusminusclass, measure="residual", scheme = "obs", type="schoenfeld")
eval_iter <- evaluationsurv(plusminusclass, measure="logplik", scheme = "iter")
eval_iter <- evaluationsurv(plusminusclass, measure="hazardratio", scheme = "iter")
eval_iter <- evaluationsurv(plusminusclass, measure="cstatistic", scheme = "iter",tau=1e6)
eval_iter <- evaluationsurv(plusminusclass, measure="plainscores", scheme = "iter")
eval_iter <- evaluationsurv(plusminusclass, measure="plainscores", scheme = "obs")


### tuning after gene selection with the t.test
##source("../R/evaluationsurv.r")
##source("../R/tune.r")
tuneres <- tune(X = PMID19318476_eset, y = c("days_to_death","vital_status","living","deceased"), learningsets = bootds,
              genesellist = list(method = "coxfilter"),
              classifier=plusminussurv, nbgene = 100,
              grids = list(lambda = c(50, 100, 250, 500, 1000)))

##------------------------------
##------------------------------
##LDA evaluation example

### simple linear discriminant analysis example using bootstrap datasets:
### datasets:
library(CMAdevel)
data(golub)
golubY <- golub[,1]
### extract gene expression from first 10 genes
golubX <- as.matrix(golub[,2:11])
### generate 25 bootstrap datasets
set.seed(333)
bootds <- GenerateLearningsets(y = golubY, method = "CV", fold=5, ntrain = 30, niter = 1, strat = TRUE)
### run classification()
ldalist <- classification(X=golubX, y=golubY, learningsets = bootds, classifier=ldaCMA)
### Evaluation:
eval_iter <- evaluation(ldalist, scheme = "iter")
eval_obs <- evaluation(ldalist, scheme = "obs")
show(eval_iter)
show(eval_obs)
summary(eval_iter)
summary(eval_obs)
### auc with boxplot
eval_auc <- evaluation(ldalist, scheme = "iter", measure = "auc")
boxplot(eval_auc)
### which observations have often been misclassified ?
obsinfo(eval_obs, threshold = 0.75)
     

