library(CMAdevel)
library(pensim)
library(survival)
data(beer.exprs)
data(beer.survival)
beerY <- with(beer.survival,Surv(os,status))
beerX <- t(as.matrix(beer.exprs))
beerX <- beerX[,1:200]
colnames(beerX) <- make.names(colnames(beerX),unique=TRUE)
beerX <- scale(beerX)  ##scale everything for testing.
##
data(golub)
golubY <- golub[,1]
golubX <- as.matrix(golub[,-1])

### select learningset
##ratio <- 2/3
##set.seed(111)
##learnind <- sample(nrow(beerY), size=floor(ratio*nrow(beerY)))

##varsel survival example:
fiveCVdat <- GenerateLearningsets(y=beerY, method = "CV", fold = 5, strat = TRUE)  ##stratification only occurs with respect to censoring
varsel_fiveCV <- GeneSelection(X = beerX, y=beerY, learningsets = fiveCVdat, method = "coxfilter")

### generate 25 bootstrap datasets
(seed <- sample(1:1e6,1))
set.seed(seed)
##source("../R/GenerateLearningsets.r")
bootds <- GenerateLearningsets(y = beerY, method = "CV", fold = 10, niter = 1, strat = TRUE)
### run classification()
##source("../R/ridgeCMA.r")
ridgeclass <- learnsurvival(X=beerX, y=beerY, learningsets = bootds, classifier=ridgeCMA, models=TRUE, probability=2.0, lambda=100)

### Evaluation:
source("../R/evaluation.r")
eval_iter <- evaluation(ridgeclass, measure="residual", scheme = "obs", type="martingale")
eval_iter <- evaluation(ridgeclass, measure="residual", scheme = "obs", type="score")
eval_iter <- evaluation(ridgeclass, measure="residual", scheme = "obs", type="deviance")
eval_iter <- evaluation(ridgeclass, measure="residual", scheme = "obs", type="schoenfeld")
eval_iter <- evaluation(ridgeclass, measure="logplik", scheme = "iter")
eval_iter@score
eval_iter <- evaluation(ridgeclass, measure="hazardratio", scheme = "iter")
eval_iter <- evaluation(ridgeclass, measure="cstatistic", scheme = "iter",tau=1e6)
eval_iter@score
eval_iter <- evaluation(ridgeclass, measure="plainscores", scheme = "iter")
eval_iter <- evaluation(ridgeclass, measure="plainscores", scheme = "obs")

ridgeclass <- learnsurvival(X=beerX[,1:2], y=beerY, learningsets = bootds, classifier=ridgeCMA, models=TRUE, probability=2.0, lambda=1e-9)
eval_iter <- evaluation(ridgeclass, measure="logplik", scheme = "iter")
eval_iter@score


### tuning after gene selection with the t.test
##source("../R/evaluation.r")
##source("../R/tune.r")
tuneres <- tune(X = beerX, y = beerY, learningsets = bootds,
                genesellist = list(method = NULL),
##              genesellist = list(method = "coxfilter"), nbgene = 100,
                classifier=ridgeCMA, 
                grids = list(lambda = c(1, 10, 100, 1000, 10000)))

### inspect results - needs work.
unlist(best(tuneres))
show(tuneres)
plot(tuneres, iter = 3)

##compare to using optL2 directly
tmp <- optL2(response=beerY,penalized=beerX)

##--------------------------------
## example using an expressionset
##--------------------------------
library(CMAdevel)
data(PMID19318476_eset)
PMID19318476_eset <- PMID19318476_eset[1:200,]

### select learningset
ratio <- 2/3
set.seed(111)
learnind <- sample(ncol(PMID19318476_eset), size=floor(ratio*ncol(PMID19318476_eset)))

##varsel survival example:
fiveCVdat <- GenerateLearningsets(y=PMID19318476_eset$vital_status, method = "CV", fold = 5, strat = TRUE)  ##stratification only occurs with respect to censoring
##source("../R/GeneSelection.r")
varsel_fiveCV <- GeneSelection(X = PMID19318476_eset, y=c("days_to_death","vital_status","living","deceased"), learningsets = fiveCVdat, method = "coxfilter")

### generate 25 bootstrap datasets
(seed <- sample(1:1e6,1))
set.seed(seed)
##source("../R/GenerateLearningsets.r")
bootds <- GenerateLearningsets(y = PMID19318476_eset$vital_status, method = "CV", fold = 5, ntrain = 3, niter = 2, strat = TRUE)
### run classification()
##source("../R/ridgeCMA.r")
##source("../R/survival.r")
ridgeclass <- learnsurvival(X=PMID19318476_eset, y=c("days_to_death","vital_status","living","deceased"), learningsets = bootds, classifier=ridgeCMA, mod=TRUE, probability=2.0, lambda=100)

### Evaluation:
##source("../R/evaluation.r")
eval_iter <- evaluation(ridgeclass, measure="residual", scheme = "obs", type="martingale")
eval_iter@score
eval_iter <- evaluation(ridgeclass, measure="residual", scheme = "obs", type="score")
eval_iter <- evaluation(ridgeclass, measure="residual", scheme = "obs", type="deviance")
eval_iter <- evaluation(ridgeclass, measure="residual", scheme = "obs", type="schoenfeld")
eval_iter <- evaluation(ridgeclass, measure="logplik", scheme = "iter")
eval_iter <- evaluation(ridgeclass, measure="hazardratio", scheme = "iter")
eval_iter <- evaluation(ridgeclass, measure="cstatistic", scheme = "iter",tau=1e6)
eval_iter <- evaluation(ridgeclass, measure="plainscores", scheme = "iter")
eval_iter <- evaluation(ridgeclass, measure="plainscores", scheme = "obs")


### tuning after gene selection with the t.test
##source("../R/evaluation.r")
##source("../R/tune.r")
tuneres <- tune(X = PMID19318476_eset, y = c("days_to_death","vital_status","living","deceased"), learningsets = bootds,
              genesellist = list(method = "coxfilter"),
              classifier=ridgeCMA, nbgene = 100,
              grids = list(lambda = c(50, 100, 250, 500, 1000)))

##------------------------------
##------------------------------
##LDA evaluation example

### simple linear discriminant analysis example using bootstrap datasets:
### datasets:
library(CMAdevel)
data(golub)
golubY <- golub[,1]
### extract gene expression from first 10 genes
golubX <- as.matrix(golub[,2:11])
### generate 25 bootstrap datasets
set.seed(333)
bootds <- GenerateLearningsets(y = golubY, method = "CV", fold=5, ntrain = 30, niter = 1, strat = TRUE)
### run classification()
ldalist <- classification(X=golubX, y=golubY, learningsets = bootds, classifier=ldaCMA)
### Evaluation:
eval_iter <- evaluation(ldalist, scheme = "iter")
eval_obs <- evaluation(ldalist, scheme = "obs")
show(eval_iter)
show(eval_obs)
summary(eval_iter)
summary(eval_obs)
### auc with boxplot
eval_auc <- evaluation(ldalist, scheme = "iter", measure = "auc")
boxplot(eval_auc)
### which observations have often been misclassified ?
obsinfo(eval_obs, threshold = 0.75)
     

