##test cross-validation

testCrossval <- function(){
    require(survHD)
    require(survival)

    set.seed(2)
    nsamples <- 100
    X <- matrix(rnorm(nsamples*200),nrow=nsamples)
    colnames(X) <- make.names(1:ncol(X))
    rownames(X) <- make.names(1:nrow(X))
    ##Illegal characters in column and row names should not break things:
    bad.characters <- c("3", "`", "@", "/", "-", " ", "	", "\n", "\\")
    colnames(X) <- paste(sample(bad.characters, ncol(X), replace=TRUE), colnames(X), sep="")
    rownames(X) <- paste(sample(bad.characters, nrow(X), replace=TRUE), rownames(X), sep="")
    time <- rexp(nsamples)
    cens <- sample(0:1,size=nsamples,replace=TRUE)
    y <- Surv(time,cens)
    ##bootds defines outer fold (evaluation):
    bootds <- generateLearningsets(y = y, method = "CV", fold = 5, niter = 1, strat = TRUE)
    ##tuneres defines inner fold (tuning)

    tuneres <- learnSurvival(X = X, y = y, learningsets = bootds,
                             survmethod="penalizedSurv",
                             tuninglist = list(grids = list(lambda = c(1e2, 1e3, 1e4, 1e5, 1e6))),
                             fold=3,
                             penalty="ridge")

    tuneres.innercv <- learnSurvival(X = X, y = y, learningsets = bootds,
                             survmethod="penalizedSurv",
                             tuninglist = list(grids = list(lambda = c(1e2, 1e3, 1e4, 1e5, 1e6))),
                             fold=3,
                             innercv=TRUE,
                             penalty="ridge")

    all.measures <- c("UnoC", "HarrellC", "CvPLogL", "PErrC")
    ##Keeping all the X from the inner folds
    all.evals <- sapply(all.measures, function(measure){
        mean(unlist(evaluate(tuneres, measure=measure, tau=10, timegrid=1)@result))
    })
    ##Pruning all the X from the inner folds
    all.evals.innercv <- try(sapply(all.measures, function(measure){
        mean(unlist(evaluate(tuneres.innercv, measure=measure, tau=10, timegrid=1,X=X)@result))
    }))

  # checkEquals(all.evals, all.evals.innercv)


}
