test_indepevalsanity <- function(){
    library(survHD)
    library(survC1)
    set.seed(2)
    nsamples <- 40
    nvar <- 80
    minisim <- function(){
        ##I use myseed to avoid survC1 synchronizing the random number generator:
        myseed <- sample(1:1e6, 1)
        ##For training:
        X1 <- matrix(rnorm(nsamples * nvar),nrow=nsamples)
        colnames(X1) <- make.names(1:ncol(X1))
        rownames(X1) <- make.names(1:nrow(X1))
        time <- rexp(nsamples)
        cens <- sample(0:1,size=nsamples,replace=TRUE)
        y1 <- Surv(time,cens)
        ##For validation:
        X2 <- matrix(rnorm(nsamples * nvar),nrow=nsamples)
        colnames(X2) <- make.names(1:ncol(X2))
        rownames(X2) <- make.names(1:nrow(X2))
        time <- rexp(nsamples)
        cens <- sample(0:1,size=nsamples,replace=TRUE)
        y2 <- Surv(time,cens)
        ##create plusMinus models on X1, two different ways:
        model <- plusMinusSurv(X=X1, y=y1)
        modelSurv <- learnSurvival(X=X1, y=y1, survmethod="plusMinusSurv")
        ##they are equivalent:
        checkEquals(model@model, modelSurv@survoutputlist[[1]]@model)
        ##manual calculation of Uno's C:
        X2preds <- predict(model, newdata=X2)@lp
        unotau1 <- Inf.Cval(mydata=cbind(y2[,1], y2[,2], X2preds), tau=0.5, itr=1)$Dhat
        unoharrell1 <- rcorr.cens(x = -X2preds, S = y2)["C Index"]
        ##using evaluate()
        unotau2 <- evaluate(modelSurv, measure="UnoC", newdata=X2, newy=y2, tau=0.5)@result[[1]]
        unoharrell2 <- evaluate(modelSurv, measure="HarrellC", newdata=X2, newy=y2)@result[[1]]
        ##finished.
        set.seed(myseed)
        return(c(unotau1, unotau2, unoharrell1, unoharrell2))
    }

    simoutput <- t( replicate( 100, minisim() ) )

    ##these must be identical!
    checkEquals(simoutput[ ,1], simoutput[ ,2])
    checkEquals(simoutput[ ,3], simoutput[ ,4])

    ##furthermore, C should be nearly 0.5:
    checkTrue( mean(simoutput[, 1]) - 0.5 < 0.005 )
    checkTrue( mean(simoutput[, 3]) - 0.5 < 0.005 )

    ##Also, make sure that the random number generator didn't get
    ##stuck by UnoC:
    checkTrue( identical(all.equal(simoutput[5, ], simoutput[6, ]), FALSE) )
    
   }
