library(survC1)
library(Hmisc)
library(survival)
set.seed(2)

nsamples <- 40
nvar <- 2

minisim <- function(){
    ##I use myseed to avoid survC1 synchronizing the random number generator:
    myseed <- sample(1:1e6, 1)
    ##For training:
    data1 <- data.frame( matrix(rnorm(nvar * nsamples),nrow=nsamples) )
    colnames(data1) <- make.names(1:ncol(data1))
    rownames(data1) <- make.names(1:nrow(data1))
    data1$time <- rexp(nsamples)
    data1$cens <- sample(0:1,size=nsamples,replace=TRUE)
    ##For validation:
    data2 <- data.frame( matrix(rnorm(nvar * nsamples),nrow=nsamples) )
    colnames(data2) <- make.names(1:ncol(data2))
    rownames(data2) <- make.names(1:nrow(data2))
    time <- rexp(nsamples)
    cens <- sample(0:1,size=nsamples,replace=TRUE)
    y2 <- Surv(time,cens)
    fit <- coxph(Surv(time, cens) ~ X1 + X2, data=data1)
    data2preds <- predict(fit, newdata=data2)
    unoC <- Inf.Cval(mydata=cbind(y2[,1], y2[,2], data2preds), tau=0.5, itr=1, seed=myseed)$Dhat
    harrellC <- rcorr.cens(x = -data2preds, S = y2)["C Index"]
    ##finished
    output <- c(unoC, harrellC)
    names(output) <- c("unoC", "harrellC")
    return(output)
}

simoutput <- t( replicate( 1000, minisim() ) )

summary(simoutput)
