\name{compare}
\alias{compare}
\alias{compare,survaggr,survaggr-method}
\alias{compare,survoutput,survoutput-method}
\alias{compareb}
\alias{compareb,survaggr,survaggr-method}
\alias{compareb,survoutput,survoutput-method}
\alias{compareb,ModelC,ModelC-method}
\alias{compareb,linpred,linpred-method}
\alias{compareb,IDI,missing-method}
\alias{compareb,NRI,missing-method}
\alias{compareb,MIRS,missing-method}

\title{Comparison of two survival methods}
\description{This function is a wrapper for the function  \code{IDI.INF} from the package survIDINRI
 which calculates the measures IDI and NRI. 
}
\usage{
\S4method{compare}{survaggr,survaggr}(obj1,obj2,t0, newdata = NULL, newy = NULL, ...)
\S4method{compare}{survoutput,survoutput}(obj1,obj2, t0, newdata, newy, ...)
}
\arguments{
  \item{obj1}{An object of class \code{survoutput} or \code{survaggr} representing the first method to be compared}
   \item{obj2}{An object of class \code{survoutput} or \code{survaggr} representing the second method to be compared}
                 \item{newdata}{if the model is to be compared on independent new data these can be specified here. If obj1 and obj2 are of class \code{survoutput} this argument is obligatory.}
                 \item{newy}{survival response for the independent test data mentioned in the previous \code{newdata} argument. It is also obligatory if obj1 and obj2 are of class \code{survoutput}.}
                 \item{t0}{A time point to define event=yes/no (case/control). Risk score is calculated as the event probability at \code{t0} for each model.}
                 \item{\dots}{ further arguments to be passed to function \code{IDI.INF}.}
                            }
      
\value{A list containing the measure IDI and NRI among many other  (see package survIDINRI for more detailed information)}
\references{ 

Hajime Uno and Tianxi Cai (2012). survIDINRI: IDI and NRI for comapring competing risk prediction models with censored survival data.

}
            

\author{Christoph Bernau \email{bernau@ibe.med.uni-muenchen.de}}

\seealso{\code{\link{learnSurvival}},\code{\link{compare-methods}}}
\examples{

library(survHD)

data(beer.exprs)
data(beer.survival)
X<-t(as.matrix(beer.exprs))
y<-Surv(beer.survival$os,beer.survival$status)
ls<-generateLearningsets(y=y,method='CV',fold=3)
gsel<-geneSelection(X=X,y=y,learningsets=ls, method='fastCox')
coxboostmodel1<-learnSurvival(y=y,X=X,survmethod='coxBoostSurv',stepno=20,learningsets=ls,genesel=gsel,nbgene=500)
coxboostmodel2<-learnSurvival(y=y,X=X,survmethod='coxBoostSurv',stepno=200,learningsets=ls,genesel=gsel,nbgene=500)
options(error=recover)
comp<-compare(coxboostmodel1,coxboostmodel2,t0=50)
###first fold
comp[[1]]$m3
	
}

\keyword{multivariate}

