\name{evaluate}
\alias{evaluate}

\alias{evaluate,survaggr-method}
\title{Evaluation of survival methods}
\description{
  The performance of survival methods can be evaluated by different
  measures that are described more precisely
  below.\cr
  For S4 method information, s. \code{\link{evaluate-methods}}.
}
\usage{
\S4method{evaluate}{survaggr}(object,measure="CvPLogL",newdata=NULL,newy=NULL,index=NULL,imputezero=FALSE,...)
}
\arguments{
  \item{object}{An object of class \code{survaggr} returned by a call to method \code{learnSurvival}.}
                  
  \item{measure}{Peformance measure to be used:
                 \describe{
                 \item{\code{"CvPLogL"}}{Cross-validated partial log likelihood}
                 \item{\code{"PErrC"}}{Prediction Error Curves}
                 \item{\code{"UnoC"}}{Uno's C-Statistic}
                 \item{\code{"HarrellC"}}{Harrell's C-Statistic}
                 }
                 }
                 \item{newdata}{if the model is to be evaluated on independent new data these can be specified here}
                 \item{newy}{survival response for the independent test data mentioned in the previous \code{newdata} argument}
                 \item{index}{the index of the model that is to be
                 evaluated (if object is of class \code{survaggr} which
                 usually conatains several models)}
	       \item{imputezero}{If TRUE, missing variables in newdata
                 will be given a value of zero.}
                \item{...}{Further arguments needed for the computation of the specified measure (s. basic measure functions in 'see also'-section).}
                            }
      
\value{An object of class \code{\link{evaloutput}}.}
\references{ 
Verweij, P.J.M. and van Houweilingen, H.C. (1993) Cross-Validation in Survival Analysis, Statistics in Medicine, 12, 2305-2314


Uno, H., et al. (2009), On The C-Statistics For Evaluating Overall Adequacy Of Risk Prediction Procedures With Censored Survival Data, Harvard University Biostatistics Working Series, Paper 101


}
            

\author{Christoph Bernau \email{bernau@ibe.med.uni-muenchen.de}}

\seealso{\code{\link{evaloutput}}, \code{\link{learnSurvival}},\code{\link{evaluate-methods}}}
\examples{
\dontrun{
library(survHD)
	data(beer.exprs)
	set.seed(123)
	X<-t(as.matrix(beer.exprs))
	data(beer.survival)
	y<-Surv(beer.survival[,2],beer.survival[,1])
	
	ls<-generateLearningsets(y=y[,1],method='CV',fold=3,niter=2)
	
	svaggr<-learnSurvival(X=X,y=y,survmethod='coxBoostSurv',learningsets=ls)
	evaluate(svaggr,measure='CvPLogL')
	evaluate(svaggr,measure='CvPLogL',newdata=X,newy=y,index=1)
	}
}

\keyword{multivariate}

