\name{Prediction from ModelC objects}
\docType{methods}
\alias{predict,ModelC-method}
\alias{predictsurvhd,ModelC,data.frame-method}

\alias{predict,PenalizedSurv-method}
\alias{predict,CoxBoostSurv-method}
\alias{predict,UniCoxSurv-method}
\alias{predict,SuperPcSurv-method}

\alias{predictsurvhd,PenalizedSurv,data.frame-method}
\alias{predictsurvhd,CoxBoostSurv,data.frame-method}
\alias{predictsurvhd,UniCoxSurv,data.frame-method}
\alias{predictsurvhd,SuperPcSurv,data.frame-method}
\alias{predictsurvhd,survhdcustom,data.frame-method}

\title{Prediction from a survival model}
\description{Predictions from a previously fitted survival model.}
\usage{

\S4method{predictsurvhd}{ModelC,data.frame}(object, newdata,type="lp",timegrid=NULL,gbm=TRUE,...)
\S4method{predict}{ModelC}(object,...)
}
\arguments{

  \item{object}{object of class \code{ModelC}}

   \item{newdata}{Gene expression data for which predictions shall be returned. The following formats are available:
  \itemize{
   \item{\code{matrix}} Rows correspond to observations, columns to variables.
   \item{\code{data.frame}}  Rows correspond to observations, columns to variables.
   \item{\code{ExpressionSet}} survHD will extract the expressions using exprs().
  } }
  \item{type}{class \code{character}, can be one of the following:
  \itemize{
  \item "lp", if the linear predictor is to be computed
  \item "survprobs", if the survival probabilities are to be computed
  }}
  \item{timegrid}{the timepoints for which the survival probabilities are to be computed}
  \item{gbm}{shall the default estimation procedure from package \code{gbm} be used for estimating the basehazard?}
  \item{\dots}{currently unused argument}
}


\author{
Christoph Bernau \email{bernau@ibe.med.uni-muenchen.de}
Levi Waldron \email{lwaldron@hsph.harvard.edu}
 Markus Riester <riester@jimmy.harvard.edu>
}

\examples{
\dontrun{
##prepare data
library(survHD)
	data(beer.exprs)
	set.seed(123)
	X<-t(as.matrix(beer.exprs))
	data(beer.survival)
	y<-Surv(beer.survival[,2],beer.survival[,1])
	
	model<-coxBoostSurv(X=X,y=y,learnind=1:nrow(X))
	lp<-predict(object=model,newdata=X,type='lp')
	survprobs<-predict(object=model,newdata=X,timegrid=1:3,type='survprobs',gbm=T)
	
	

}

}
\seealso{\code{\link{gbmbasehaz}}}

\keyword{multivariate}